@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/src/widgets/qradiobutton.cpp   2.3.0   edited 2001-01-26 $
+** $Id: qt/src/widgets/qradiobutton.cpp   2.3.1   edited 2001-04-18 $
 **
 ** Implementation of QRadioButton class
 **
@@ -206,7 +206,7 @@ void QRadioButton::drawButton( QPainter *paint )
     QFontMetrics fm = fontMetrics();
     QSize lsz = fm.size(ShowPrefix, text());
     QSize sz = style().exclusiveIndicatorSize();
-    x = 0;
+    x = text().isEmpty() ? 1 : 0;
     y = (height() - lsz.height() + fm.height() - sz.height())/2;
 
 #ifndef QT_NO_TEXTSTREAM
@@ -301,7 +301,15 @@ void QRadioButton::drawButtonLabel( QPainter *p )
 	br.setBottom( br.bottom()+2);
 	br = br.intersect( QRect(0,0,width(),height()) );
 
-	style().drawFocusRect(p, br, colorGroup());
+	if ( !text().isEmpty() )
+	    style().drawFocusRect( p, br, colorGroup() );
+	else {
+	    br.setRight( br.left()-1 );
+	    br.setLeft( br.left()-16 );
+	    br.setTop( br.top() );
+	    br.setBottom( br.bottom() );
+	    style().drawFocusRect( p, br, colorGroup() );
+	}
     }
 }
 
@@ -378,7 +386,16 @@ void QRadioButton::updateMask()
 	    br.setBottom( br.bottom()+2);
 	    br = br.intersect( QRect(0,0,width(),height()) );
 
-	    style().drawFocusRect( &p, br, cg );
+	    if ( !text().isEmpty() )
+		style().drawFocusRect( &p, br, cg );
+	    else {
+		br.setRight( br.left()-1 );
+		br.setLeft( br.left()-16 );
+		br.setTop( br.top() );
+		br.setBottom( br.bottom() );
+		style().drawFocusRect( &p, br, cg );
+	    }
+
 	}
     }
     setMask(bm);
