@@ -21,15 +21,21 @@
 #include <qpopupmenu.h>
 #include <qapplication.h>
 #include <qmessagebox.h>
+#include <qcombobox.h>
+#include <qlabel.h>
 #include <qfiledialog.h>
+#include <qslider.h>
 #include <qspinbox.h>
 #include <qradiobutton.h>
 #include <qimage.h>
+#include <qpixmap.h>
+
 
 #include "qvfb.h"
 #include "qvfbview.h"
 #include "qvfbratedlg.h"
 #include "config.h"
+#include "skin.h"
 
 
 static const char * logo[] = {
@@ -106,30 +112,65 @@ static const char * logo[] = {
 "/$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$/",
 };
 
-QVFb::QVFb( int display_id, int w, int h, int d, QWidget *parent,
+QVFb::QVFb( int display_id, int w, int h, int d, const QString &skin, QWidget *parent,
 	    const char *name, uint flags )
     : QMainWindow( parent, name, flags )
 {
+    imagesave = new QFileDialog(".", "*.png", this, 0, TRUE);
+    imagesave->setSelection("snapshot.png");
     setIcon(QPixmap(logo));
     rateDlg = 0;
     view = 0;
-    init( display_id, w, h, d );
-    createMenu();
+    init( display_id, w, h, d, skin );
+    createMenu( menuBar() );
 }
 
 QVFb::~QVFb()
 {
 }
 
-void QVFb::init( int display_id, int w, int h, int d )
+void QVFb::popupMenu()
+{
+    QPopupMenu *pm = new QPopupMenu( this );
+    createMenu( pm );
+    pm->exec(QCursor::pos());
+}
+
+void QVFb::init( int display_id, int w, int h, int d, const QString &skin_name )
 {
     setCaption( QString("Virtual framebuffer %1x%2 %3bpp Display :%4")
 		    .arg(w).arg(h).arg(d).arg(display_id) );
     delete view;
-    view = new QVFbView( display_id, w, h, d, this );
-    setCentralWidget( view );
-    if ( isVisible() )
+
+    if ( !skin_name.isEmpty() && QFile::exists(skin_name) ) {
+	bool vis = isVisible();
+	if ( vis ) hide();
+	menuBar()->hide();
+	Skin *skin = new Skin( this, skin_name, w, h );
+	view = new QVFbView( display_id, w, h, d, skin );
+	skin->setView( view );
+	view->setMargin( 0 );
+	view->setFrameStyle( QFrame::NoFrame );
+	view->setFixedSize( w, h );
+	setCentralWidget( skin );
 	adjustSize();
+	view->show(); 
+	if ( vis ) show();
+    } else {
+	if ( !currentSkin.isEmpty() ) {
+	    clearMask();
+	    reparent( 0, 0, pos(), TRUE );
+	}
+	menuBar()->show();
+	view = new QVFbView( display_id, w, h, d, this );
+	view->setMargin( 0 );
+	view->setFrameStyle( QFrame::NoFrame );
+	setCentralWidget( view );
+	resize(w,menuBar()->height()+h);
+	view->show(); 
+    }
+
+    currentSkin = skin_name;
 }
 
 void QVFb::enableCursor( bool e )
@@ -138,7 +179,7 @@ void QVFb::enableCursor( bool e )
     viewMenu->setItemChecked( cursorId, e );
 }
 
-void QVFb::createMenu()
+void QVFb::createMenu(QMenuData *menu)
 {
     QPopupMenu *file = new QPopupMenu( this );
     file->insertItem( "&Configure...", this, SLOT(configure()), ALT+CTRL+Key_C );
@@ -148,7 +189,7 @@ void QVFb::createMenu()
     file->insertSeparator();
     file->insertItem( "&Quit", qApp, SLOT(quit()) );
 
-    menuBar()->insertItem( "&File", file );
+    menu->insertItem( "&File", file );
 
     viewMenu = new QPopupMenu( this );
     viewMenu->setCheckable( true );
@@ -162,12 +203,12 @@ void QVFb::createMenu()
     viewMenu->insertItem( "Zoom scale &4", this, SLOT(setZoom4()) );
     viewMenu->insertItem( "Zoom scale &0.5", this, SLOT(setZoomHalf()) );
 
-    menuBar()->insertItem( "&View", viewMenu );
+    menu->insertItem( "&View", viewMenu );
 
     QPopupMenu *help = new QPopupMenu( this );
     help->insertItem("About...", this, SLOT(about()));
-    menuBar()->insertSeparator();
-    menuBar()->insertItem( "&Help", help );
+    menu->insertSeparator();
+    menu->insertItem( "&Help", help );
 }
 
 void QVFb::setZoom(double z)
@@ -200,13 +241,14 @@ void QVFb::setZoom4()
     setZoom(4);
 }
 
-
 void QVFb::saveImage()
 {
     QImage img = view->image();
-    QString filename = QFileDialog::getSaveFileName("snapshot.png", "*.png", this, "", "Save snapshot...");
-    if ( !!filename )
-	img.save(filename,"PNG");
+    if ( imagesave->exec() ) {
+	QString filename = imagesave->selectedFile();
+	if ( !!filename )
+	    img.save(filename,"PNG");
+    }
 }
 
 void QVFb::toggleAnimation()
@@ -214,7 +256,7 @@ void QVFb::toggleAnimation()
     if ( view->animating() ) {
 	view->stopAnimation();
     } else {
-	QString filename = QFileDialog::getSaveFileName("animation.mng", "*.mng", this, "", "Save animation...");
+	QString filename = imagesave->getSaveFileName("animation.mng", "*.mng", this, "", "Save animation...");
 	if ( !filename ) {
 	    view->stopAnimation();
 	} else {
@@ -254,47 +296,131 @@ void QVFb::about()
 
 void QVFb::configure()
 {
-    Config config(this,0,TRUE);
+    config = new Config(this,0,TRUE);
 
     int w = view->displayWidth();
     int h = view->displayHeight();
-    config.size_width->setValue(w);
-    config.size_height->setValue(h);
-    config.size_custom->setChecked(TRUE); // unless changed by settings below
-    config.size_240_320->setChecked(w==240&&h==320);
-    config.size_320_240->setChecked(w==320&&h==240);
-    config.size_640_480->setChecked(w==640&&h==480);
-    config.depth_1->setChecked(view->displayDepth()==1);
-    config.depth_4gray->setChecked(view->displayDepth()==4);
-    config.depth_8->setChecked(view->displayDepth()==8);
-    config.depth_16->setChecked(view->displayDepth()==16);
-    config.depth_32->setChecked(view->displayDepth()==32);
+    QString skin;
+    config->size_width->setValue(w);
+    config->size_height->setValue(h);
+    config->size_custom->setChecked(TRUE); // unless changed by settings below
+    config->size_240_320->setChecked(w==240&&h==320);
+    config->size_320_240->setChecked(w==320&&h==240);
+    config->size_640_480->setChecked(w==640&&h==480);
+    config->skin->setEditable(TRUE);
+    if (!currentSkin.isNull()) {
+	config->size_skin->setChecked(TRUE);
+	config->skin->setEditText(currentSkin);
+    }
+    config->depth_1->setChecked(view->displayDepth()==1);
+    config->depth_4gray->setChecked(view->displayDepth()==4);
+    config->depth_8->setChecked(view->displayDepth()==8);
+    config->depth_12->setChecked(view->displayDepth()==12);
+    config->depth_16->setChecked(view->displayDepth()==16);
+    config->depth_32->setChecked(view->displayDepth()==32);
+    if ( view->gammaRed() == view->gammaGreen() && view->gammaGreen() == view->gammaBlue() ) {
+	config->gammaslider->setValue(int(view->gammaRed()*400));
+	config->rslider->setValue(100);
+	config->gslider->setValue(100);
+	config->bslider->setValue(100);
+    } else {
+	config->gammaslider->setValue(100);
+	config->rslider->setValue(int(view->gammaRed()*400));
+	config->gslider->setValue(int(view->gammaGreen()*400));
+	config->bslider->setValue(int(view->gammaBlue()*400));
+    }
+    connect(config->gammaslider, SIGNAL(valueChanged(int)), this, SLOT(setGamma400(int)));
+    connect(config->rslider, SIGNAL(valueChanged(int)), this, SLOT(setR400(int)));
+    connect(config->gslider, SIGNAL(valueChanged(int)), this, SLOT(setG400(int)));
+    connect(config->bslider, SIGNAL(valueChanged(int)), this, SLOT(setB400(int)));
+    updateGammaLabels();
 
-    if ( config.exec() ) {
+    double ogr=view->gammaRed(), ogg=view->gammaGreen(), ogb=view->gammaBlue();
+
+    if ( config->exec() ) {
 	int id = view->displayId(); // not settable yet
-	if ( config.size_240_320->isChecked() ) {
+	if ( config->size_240_320->isChecked() ) {
 	    w=240; h=320;
-	} else if ( config.size_320_240->isChecked() ) {
+	} else if ( config->size_320_240->isChecked() ) {
 	    w=320; h=240;
-	} else if ( config.size_640_480->isChecked() ) {
+	} else if ( config->size_640_480->isChecked() ) {
 	    w=640; h=480;
+	} else if ( config->size_skin->isChecked() ) {
+	    skin = config->skin->currentText();
 	} else {
-	    w=config.size_width->value();
-	    h=config.size_height->value();
+	    w=config->size_width->value();
+	    h=config->size_height->value();
 	}
 	int d;
-	if ( config.depth_1->isChecked() )
+	if ( config->depth_1->isChecked() )
 	    d=1;
-	else if ( config.depth_4gray->isChecked() )
+	else if ( config->depth_4gray->isChecked() )
 	    d=4;
-	else if ( config.depth_8->isChecked() )
+	else if ( config->depth_8->isChecked() )
 	    d=8;
-	else if ( config.depth_16->isChecked() )
+	else if ( config->depth_12->isChecked() )
+	    d=12;
+	else if ( config->depth_16->isChecked() )
 	    d=16;
 	else
 	    d=32;
 
-	init( id, w, h, d );
+	if ( w != view->displayWidth() || h != view->displayHeight() 
+		|| d != view->displayDepth() || skin != currentSkin )
+	    init( id, w, h, d, skin );
+    } else {
+	view->setGamma(ogr, ogg, ogb);
     }
+
+    delete config;
+    config=0;
 }
 
+void QVFb::setGamma400(int n)
+{
+    double g = n/100.0;
+    view->setGamma(config->rslider->value()/100.0*g,
+                   config->gslider->value()/100.0*g,
+                   config->bslider->value()/100.0*g);
+    updateGammaLabels();
+}
+
+void QVFb::setR400(int n)
+{
+    double g = n/100.0;
+    view->setGamma(config->rslider->value()/100.0*g,
+                   view->gammaGreen(),
+                   view->gammaBlue());
+    updateGammaLabels();
+}
+
+void QVFb::setG400(int n)
+{
+    double g = n/100.0;
+    view->setGamma(view->gammaRed(),
+                   config->gslider->value()/100.0*g,
+                   view->gammaBlue());
+    updateGammaLabels();
+}
+
+void QVFb::setB400(int n)
+{
+    double g = n/100.0;
+    view->setGamma(view->gammaRed(),
+                   view->gammaGreen(),
+                   config->bslider->value()/100.0*g);
+    updateGammaLabels();
+}
+
+void QVFb::updateGammaLabels()
+{
+    config->rlabel->setText(QString::number(view->gammaRed(),'g',2));
+    config->glabel->setText(QString::number(view->gammaGreen(),'g',2));
+    config->blabel->setText(QString::number(view->gammaBlue(),'g',2));
+}
+
+QSize QVFb::sizeHint() const
+{
+    return QSize(view->displayWidth()*view->zoom(),
+	    menuBar()->height()+view->displayHeight()*view->zoom());
+}
